#ifndef EXT_PSK_KE_MODES_H
#define EXT_PSK_KE_MODES_H

#include <hello_ext.h>

extern const hello_ext_entry_st ext_mod_psk_ke_modes;

#endif
